/***************************************************************************
* File Name: ECG_DMA_dma.c  
* Version 1.50
*
*  Description:
*   Provides an API for the DMAC component. The API includes functions
*   for the DMA controller, DMA channels and Transfer Descriptors.
*
*
*   Note:
*     This module requires the developer to finish or fill in the auto
*     generated funcions and setup the dma channel and TD's.
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include <CYLIB.H>
#include <CYDMAC.H>
#include <ECG_DMA_dma.H>



/****************************************************************************
* 
* The following defines are available in Cyfitter.h
* 
* 
* 
* ECG_DMA__DRQ_CTL_REG
* 
* 
* ECG_DMA__DRQ_NUMBER
* 
* Number of TD's used by this channel.
* ECG_DMA__NUMBEROF_TDS
* 
* Priority of this channel.
* ECG_DMA__PRIORITY
* 
* True if ECG_DMA_TERMIN_SEL is used.
* ECG_DMA__TERMIN_EN
* 
* TERMIN interrupt line to signal terminate.
* ECG_DMA__TERMIN_SEL
* 
* 
* True if ECG_DMA_TERMOUT0_SEL is used.
* ECG_DMA__TERMOUT0_EN
* 
* 
* TERMOUT0 interrupt line to signal completion.
* ECG_DMA__TERMOUT0_SEL
* 
* 
* True if ECG_DMA_TERMOUT1_SEL is used.
* ECG_DMA__TERMOUT1_EN
* 
* 
* TERMOUT1 interrupt line to signal completion.
* ECG_DMA__TERMOUT1_SEL
* 
****************************************************************************/


/* Zero based index of ECG_DMA dma channel */
uint8 ECG_DMA_DmaHandle = DMA_INVALID_CHANNEL;

/*********************************************************************
* Function Name: uint8 ECG_DMA_DmaInitalize
**********************************************************************
* Summary:
*   Allocates and initialises a channel of the DMAC to be used by the
*   caller.
*
* Parameters:
*   BurstCount.
*       
*       
*   ReqestPerBurst.
*       
*       
*   UpperSrcAddress.
*       
*       
*   UpperDestAddress.
*       
*
* Return:
*   The channel that can be used by the caller for DMA activity.
*   DMA_INVALID_CHANNEL (0xFF) if there are no channels left. 
*
*
*******************************************************************/
uint8 ECG_DMA_DmaInitialize(uint8 BurstCount, uint8 ReqestPerBurst, uint16 UpperSrcAddress, uint16 UpperDestAddress)
{

    /* Allocate a DMA channel. */
    ECG_DMA_DmaHandle = ECG_DMA__DRQ_NUMBER;

    if(ECG_DMA_DmaHandle != DMA_INVALID_CHANNEL)
    {
        /* Configure the channel. */
        CyDmaChSetConfiguration(ECG_DMA_DmaHandle,
                                BurstCount,
                                ReqestPerBurst,
                                ECG_DMA__TERMOUT0_SEL,
                                ECG_DMA__TERMOUT1_SEL,
                                ECG_DMA__TERMIN_SEL);

        /* Set the extended address for the transfers */
        CyDmaChSetExtendedAddress(ECG_DMA_DmaHandle, UpperSrcAddress, UpperDestAddress);

        /* Set the priority for this channel */
        CyDmaChPriority(ECG_DMA_DmaHandle, ECG_DMA__PRIORITY);
    }

    return ECG_DMA_DmaHandle;
}

/*********************************************************************
* Function Name: void ECG_DMA_DmaRelease
**********************************************************************
* Summary:
*   Frees the channel associated with ECG_DMA.
*
*
* Parameters:
*   void.
*
*
*
* Return:
*   void.
*
*******************************************************************/
void ECG_DMA_DmaRelease(void) 
{
    /* Disable the channel, even if someone just did! */
    CyDmaChDisable(ECG_DMA_DmaHandle);


    /* Free Transfer Descriptors. */


}

