/*******************************************************************************
* File Name: Filter.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Filter.h"


/*******************************************************************************
* Function Name: Filter_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Filter_Write(uint8 value) 
{
    uint8 staticBits = Filter_DR & ~Filter_MASK;
    Filter_DR = staticBits | ((value << Filter_SHIFT) & Filter_MASK);
}


/*******************************************************************************
* Function Name: Filter_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Filter_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Filter_0, mode);
}


/*******************************************************************************
* Function Name: Filter_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Filter_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Filter_Read(void) 
{
    return (Filter_PS & Filter_MASK) >> Filter_SHIFT;
}


/*******************************************************************************
* Function Name: Filter_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Filter_ReadDataReg(void) 
{
    return (Filter_DR & Filter_MASK) >> Filter_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Filter_INTSTAT) 

    /*******************************************************************************
    * Function Name: Filter_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Filter_ClearInterrupt(void) 
    {
        return (Filter_INTSTAT & Filter_MASK) >> Filter_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
