/*******************************************************************************
* File Name: IDAC_TEST.h  
* Version 1.60
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Current DAC (IDAC8) User Module.
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_IDAC8_IDAC_TEST_H)  
#define CY_IDAC8_IDAC_TEST_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define IDAC_TEST_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define IDAC_TEST_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define IDAC_TEST_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define IDAC_TEST_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct IDAC_TEST_backupStruct
{
    uint8 enableState;
    uint8 data_value;
}IDAC_TEST_backupStruct;


/***************************************
*        Function Prototypes 
***************************************/

void    IDAC_TEST_Start(void);
void    IDAC_TEST_Stop(void) ;
void    IDAC_TEST_SetSpeed(uint8 speed) ;
void    IDAC_TEST_SetPolarity(uint8 polarity) ;
void    IDAC_TEST_SetRange(uint8 iRange) ;
void    IDAC_TEST_SetValue(uint8 value) ;
void    IDAC_TEST_DacTrim(void) ;

/* Sleep Retention APIs */
void IDAC_TEST_Init(void) ;
void IDAC_TEST_Enable(void) ;
void IDAC_TEST_SaveConfig(void);
void IDAC_TEST_RestoreConfig(void);
void IDAC_TEST_Sleep(void);
void IDAC_TEST_Wakeup(void);
 
  
/***************************************
*       Paramater Initial Values
***************************************/

#define IDAC_TEST_DEFAULT_RANGE    4u      /* Default DAC range */
#define IDAC_TEST_DEFAULT_SPEED    ((0u ? 1u:0u)*2)  /* Default DAC speed */
#define IDAC_TEST_DEFAULT_CNTL     0x00u             /* Default Control */
#define IDAC_TEST_DEFAULT_STRB     0u    /* Default Strobe mode */
#define IDAC_TEST_DEFAULT_DATA     127u  /* Initial DAC value */
#define IDAC_TEST_DEFAULT_POLARITY 0u       /* Default Sink or Source */
#define IDAC_TEST_DEFAULT_DATA_SRC 0u    /* Default Data Source */


/***************************************
*              API Constants        
***************************************/

/* SetRange constants */

#define IDAC_TEST_RANGE_32uA     (0x00u)
#define IDAC_TEST_RANGE_255uA    (0x04u)
#define IDAC_TEST_RANGE_2mA      (0x08u)

/* SetPolarity constants */
#define IDAC_TEST_SOURCE         (0x00u)
#define IDAC_TEST_SINK           (0x04u)

/* Power setting for SetSpeed API  */
#define IDAC_TEST_LOWSPEED       (0x00u)
#define IDAC_TEST_HIGHSPEED      (0x02u)


/***************************************
*              Registers        
***************************************/

#define IDAC_TEST_CR0        (* (reg8 *) IDAC_TEST_viDAC8__CR0 )
#define IDAC_TEST_CR1        (* (reg8 *) IDAC_TEST_viDAC8__CR1 )
#define IDAC_TEST_Data       (* (reg8 *) IDAC_TEST_viDAC8__D )
#define IDAC_TEST_Data_PTR   (  (reg8 *) IDAC_TEST_viDAC8__D )
#define IDAC_TEST_Strobe     (* (reg8 *) IDAC_TEST_viDAC8__STROBE )
#define IDAC_TEST_SW0        (* (reg8 *) IDAC_TEST_viDAC8__SW0 )
#define IDAC_TEST_SW2        (* (reg8 *) IDAC_TEST_viDAC8__SW2 )
#define IDAC_TEST_SW3        (* (reg8 *) IDAC_TEST_viDAC8__SW3 )
#define IDAC_TEST_SW4        (* (reg8 *) IDAC_TEST_viDAC8__SW4 )
#define IDAC_TEST_TR         (* (reg8 *) IDAC_TEST_viDAC8__TR )
#define IDAC_TEST_PWRMGR     (* (reg8 *) IDAC_TEST_viDAC8__PM_ACT_CFG )  /* Power manager */
#define IDAC_TEST_STBY_PWRMGR (* (reg8 *) IDAC_TEST_viDAC8__PM_STBY_CFG )  /* Standby Power manager */


/***********************************************************************************
*              Trim    
*
* Note - VIDAC trim values are stored in the "Customer Table" area in 
* Row 1 of the Hidden Flash.  There are 8 bytes of trim data for each VIDAC block.
* The values are:
*       I Gain offset, min range, Sourcing
*       I Gain offset, min range, Sinking
*       I Gain offset, med range, Sourcing
*       I Gain offset, med range, Sinking
*       I Gain offset, max range, Sourcing
*       I Gain offset, max range, Sinking
*       V Gain offset, 1V range
*       V Gain offset, 4V range
*
* The data set for the 4 VIDACs are arranged using a left side/right side approach:
*   Left 0, Left 1, Right 0, Right 1.
* When mapped to the VIDAC0 thru VIDAC3 as:
*   VIDAC 0, VIDAC 2, VIDAC 1, VIDAC 3
****************************************************************************************/

#define IDAC_TEST_DAC_TRIM_BASE   IDAC_TEST_viDAC8__TRIM__M1


/***************************************
*         Register Constants       
***************************************/

/* CR0 iDAC Control Register 0 definitions */  

/* Bit Field  DAC_HS_MODE                  */
#define IDAC_TEST_HS_MASK        (0x02u)
#define IDAC_TEST_HS_LOWPOWER    (0x00u)
#define IDAC_TEST_HS_HIGHSPEED   (0x02u)

/* Bit Field  DAC_MODE                  */
#define IDAC_TEST_MODE_MASK      (0x10u)
#define IDAC_TEST_MODE_V         (0x00u)
#define IDAC_TEST_MODE_I         (0x10u)

/* Bit Field  DAC_RANGE                  */
#define IDAC_TEST_RANGE_MASK     (0x0Cu)
#define IDAC_TEST_RANGE_0        (0x00u)
#define IDAC_TEST_RANGE_1        (0x04u)
#define IDAC_TEST_RANGE_2        (0x08u)
#define IDAC_TEST_RANGE_3        (0x0Cu)

/* CR1 iDAC Control Register 1 definitions */

/* Bit Field  DAC_MX_DATA                  */
#define IDAC_TEST_SRC_MASK       (0x20u)
#define IDAC_TEST_SRC_REG        (0x00u)
#define IDAC_TEST_SRC_UDB        (0x20u)

/* This bit enable reset from UDB array      */
#define IDAC_TEST_RESET_MASK     (0x10u)
#define IDAC_TEST_RESET_ENABLE   (0x10u)
#define IDAC_TEST_RESET_DISABLE  (0x00u)

/* Bit Field  DAC_MX_IDIR_SRC              */
#define IDAC_TEST_IDIR_SRC_MASK  (0x08u)
#define IDAC_TEST_IDIR_SRC_REG   (0x00u)
#define IDAC_TEST_IDIR_SRC_UDB   (0x08u)

/* Bit Field  DAC_I_DIR                  */
/* Register control of current direction      */
#define IDAC_TEST_IDIR_MASK      (0x04u)   
#define IDAC_TEST_IDIR_SRC       (0x00u)
#define IDAC_TEST_IDIR_SINK      (0x04u)

/* Bit Field  DAC_MX_IOFF_SRC                  */
/* Selects source of IOFF control, reg or UDB  */
#define IDAC_TEST_IDIR_CTL_MASK  (0x02u)
#define IDAC_TEST_IDIR_CTL_REG   (0x00u)
#define IDAC_TEST_IDIR_CTL_UDB   (0x02u)

/* Bit Field  DAC_MX_IOFF                   */
/* Register control of IDAC                 */
/* Only valid if IOFF CTL is set to Reg     */
#define IDAC_TEST_I_OFF_MASK     (0x01u)   
#define IDAC_TEST_I_OFF          (0x00u)
#define IDAC_TEST_I_ON           (0x01u)

/* This bit enables data from DAC bus      */
#define IDAC_TEST_DACBUS_MASK    (0x20u)
#define IDAC_TEST_DACBUS_ENABLE  (0x20u)
#define IDAC_TEST_DACBUS_DISABLE (0x00u)

/* DAC STROBE Strobe Control Register definitions */

/* Bit Field  DAC_MX_STROBE                  */
#define IDAC_TEST_STRB_MASK      (0x08u)
#define IDAC_TEST_STRB_EN        (0x08u)
#define IDAC_TEST_STRB_DIS       (0x00u)

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define IDAC_TEST_ACT_PWR_EN   IDAC_TEST_viDAC8__PM_ACT_MSK  /* Power enable mask */ 
#define IDAC_TEST_STBY_PWR_EN  IDAC_TEST_viDAC8__PM_STBY_MSK  /* Standby Power enable mask */ 

#endif /* CY_IDAC8_IDAC_TEST_H  */


/*  [] END OF FILE  */
