/*******************************************************************************
* File Name: IDAC_TEST_PM.c  
* Version 1.60
*
*  Description:
*     This file provides the power management source code to API for the
*     IDAC8.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "IDAC_TEST.h"

static IDAC_TEST_backupStruct IDAC_TEST_backup;


/*******************************************************************************
* Function Name: IDAC_TEST_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void IDAC_TEST_SaveConfig(void)
{
    IDAC_TEST_backup.data_value = IDAC_TEST_Data;
}


/*******************************************************************************
* Function Name: IDAC_TEST_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void IDAC_TEST_RestoreConfig(void)
{
    IDAC_TEST_Data = IDAC_TEST_backup.data_value;
}


/*******************************************************************************
* Function Name: IDAC_TEST_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  IDAC_TEST_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
*******************************************************************************/
void IDAC_TEST_Sleep(void)
{
    if(IDAC_TEST_ACT_PWR_EN == (IDAC_TEST_PWRMGR & IDAC_TEST_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        IDAC_TEST_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        IDAC_TEST_backup.enableState = 0u;
    }
    
    IDAC_TEST_Stop();
    IDAC_TEST_SaveConfig();
}


/*******************************************************************************
* Function Name: IDAC_TEST_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  IDAC_TEST_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void IDAC_TEST_Wakeup(void)
{
    IDAC_TEST_RestoreConfig();
    
    if(IDAC_TEST_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        IDAC_TEST_Enable();
       
        /* Set the data register */
        IDAC_TEST_SetValue(IDAC_TEST_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
