/*******************************************************************************
* File Name: LP_Filter.h
* Version 1.50
*
* Description:
*  This header file contains definitions associated with the FILT component.
*
* Note:
* 
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(LP_Filter_H) /* FILT Header File */
#define LP_Filter_H

#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define LP_Filter_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define LP_Filter_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define LP_Filter_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define LP_Filter_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/***************************************
*     Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _LP_Filter_backupStruct 
{
    uint8 enableState;
    uint8 cr;
    uint8 sr;
    uint8 sema;
    uint8 acu_ram[64];
}   LP_Filter_BACKUP_STRUCT;


/***************************************
* FILT component function prototypes.
****************************************/

void   LP_Filter_Start(void);
void   LP_Filter_Stop(void) ;
uint8 LP_Filter_Read8(uint8 channel) ;
uint16 LP_Filter_Read16(uint8 channel) ;
uint32 LP_Filter_Read24(uint8 channel) ;
void LP_Filter_Write8(uint8 channel, uint8 sample) ;
void LP_Filter_Write16(uint8 channel, uint16 sample) ;
void LP_Filter_Write24(uint8 channel, uint32 sample) ;
void LP_Filter_Sleep(void);
void LP_Filter_Wakeup(void) ;
void LP_Filter_SaveConfig(void);
void LP_Filter_RestoreConfig(void) ;
void LP_Filter_Init(void) ;
void LP_Filter_Enable(void) ;


/*****************************************
* FILT component API Constants.
******************************************/

/* Channel Definitions */
#define LP_Filter_CHANNEL_A             (0u)
#define LP_Filter_CHANNEL_B             (1u)

#define LP_Filter_CHANNEL_A_INTR        (0x08u)
#define LP_Filter_CHANNEL_B_INTR        (0x10u)

#define LP_Filter_ALL_INTR              (0xf8u)

#define LP_Filter_SIGN_BIT              (0x00800000u)
#define LP_Filter_SIGN_BYTE             (0xFF000000u)

/* Component's enable/disable state */
#define LP_Filter_ENABLED               (0x01u)
#define LP_Filter_DISABLED              (0x00u)


/*******************************************************************************
* FILT component macros.
*******************************************************************************/

#define LP_Filter_ClearInterruptSource() \
    do { \
    LP_Filter_SR_REG = LP_Filter_ALL_INTR; \
    } while (0)

#define LP_Filter_IsInterruptChannelA() \
    (LP_Filter_SR_REG & LP_Filter_CHANNEL_A_INTR)

#define LP_Filter_IsInterruptChannelB() \
    (LP_Filter_SR_REG & LP_Filter_CHANNEL_B_INTR)


/*******************************************************************************
* FILT component DFB registers.
*******************************************************************************/

/* DFB Status register */
#define LP_Filter_SR_REG             (* (reg8 *) LP_Filter_DFB__SR)
#define LP_Filter_SR_PTR             (  (reg8 *) LP_Filter_DFB__SR)

/* DFB Control register */
#define LP_Filter_CR_REG             (* (reg8 *) LP_Filter_DFB__CR)
#define LP_Filter_CR_PTR             (  (reg8 *) LP_Filter_DFB__CR)

#endif /* End FILT Header File */


/* [] END OF FILE */
