/*******************************************************************************
* File Name: LP_Filter_PM.c
* Version 1.50
*
* Description:
*  This file provides the power managaer API source code for the FILT component.
*
* Note:
*  
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "LP_Filter_PVT.h"

static LP_Filter_BACKUP_STRUCT  LP_Filter_backup = 
{
    LP_Filter_DISABLED,
    LP_Filter_RUN_MASK,
    
};


/*******************************************************************************
* Function Name: LP_Filter_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  LP_Filter_backup:  This global structure variable is used to store 
*  configuration registers which are non retention whenever user wants to go 
*  sleep mode by calling Sleep() API.
*
* Reentrance:
*  No
*
*******************************************************************************/
void LP_Filter_SaveConfig(void)
{
    LP_Filter_backup.cr = LP_Filter_CR_REG;
    LP_Filter_backup.sr = LP_Filter_SR_REG;
    LP_Filter_backup.sema = LP_Filter_SEMA_REG;
    cymemcpy(LP_Filter_backup.acu_ram, LP_Filter_ACU_RAM, LP_Filter_ACU_RAM_SIZE); 
}


/*******************************************************************************
* Function Name: LP_Filter_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  LP_Filter_backup:  This global structure variable is used to restore 
*  configuration registers which are non retention whenever user wants to switch 
*  to active power mode by calling Wakeup() API.
*
* Reentrance:
*  No
*
*******************************************************************************/
void LP_Filter_RestoreConfig(void) 
{
    LP_Filter_CR_REG = LP_Filter_backup.cr;
    LP_Filter_SR_REG = LP_Filter_backup.sr;
    LP_Filter_SEMA_REG = LP_Filter_backup.sema;
    cymemcpy(LP_Filter_ACU_RAM, LP_Filter_backup.acu_ram, LP_Filter_ACU_RAM_SIZE); 
}


/*******************************************************************************
* Function Name: LP_Filter_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  LP_Filter_backup:  The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
* Reentrance:
*  No
*
*******************************************************************************/
void LP_Filter_Sleep(void)
{
    /* Save Filter enable state */
    if(LP_Filter_PM_ACT_MSK == (LP_Filter_PM_ACT_CFG_REG & LP_Filter_PM_ACT_MSK))
    {
        /* Component is enabled */
        LP_Filter_backup.enableState = LP_Filter_ENABLED;
    }
    else
    {
        /* Component is disabled */
        LP_Filter_backup.enableState = LP_Filter_DISABLED;
    }

    /* Stop the configuration */
    LP_Filter_Stop();

    /* Save the configuration */
    LP_Filter_SaveConfig();
}


/*******************************************************************************
* Function Name: LP_Filter_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  LP_Filter_backup:  The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
* Reentrance:
*  No
*
*******************************************************************************/
void LP_Filter_Wakeup(void) 
{
    /* Restore the configuration */
    LP_Filter_RestoreConfig();
    
    /* Enable's the component operation */
    if(LP_Filter_backup.enableState == LP_Filter_ENABLED)
    {
        LP_Filter_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
