/*******************************************************************************
* File Name: VDAC_REF_1.c  
* Version 1.60
*
*  Description:
*    This file provides the source code to the API for the 8-bit Voltage DAC 
*    (VDAC8) User Module.
*
*   Note:
*     Any unusual or non-standard behavior should be noted here. Other-
*     wise, this section should remain blank.
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "VDAC_REF_1.h"

uint8 VDAC_REF_1_initVar = 0;


/*******************************************************************************
* Function Name: VDAC_REF_1_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void:  
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects: 
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_Init(void) 
{
    VDAC_REF_1_CR0 = (VDAC_REF_1_MODE_V )  ;    

    /* Set default data source */
    if(VDAC_REF_1_DEFAULT_DATA_SRC != 0 )    
    {
        VDAC_REF_1_CR1 = (VDAC_REF_1_DEFAULT_CNTL | VDAC_REF_1_DACBUS_ENABLE) ;   
    }
    else
    {
        VDAC_REF_1_CR1 = (VDAC_REF_1_DEFAULT_CNTL | VDAC_REF_1_DACBUS_DISABLE) ;  
    } 
    
    /* Set default strobe mode */
    if(VDAC_REF_1_DEFAULT_STRB != 0)
    {
        VDAC_REF_1_Strobe |= VDAC_REF_1_STRB_EN ;
    }
    
    /* Set default range */
    VDAC_REF_1_SetRange(VDAC_REF_1_DEFAULT_RANGE); 
    
    /* Set default speed */
    VDAC_REF_1_SetSpeed(VDAC_REF_1_DEFAULT_SPEED);
}


/*******************************************************************************
* Function Name: VDAC_REF_1_Enable
********************************************************************************
* Summary:
*     Enable the VDAC8
* 
* Parameters:  
*  void:  
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects: 
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_Enable(void) 
{
    VDAC_REF_1_PWRMGR |= VDAC_REF_1_ACT_PWR_EN;
    VDAC_REF_1_STBY_PWRMGR |= VDAC_REF_1_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: VDAC_REF_1_Start
********************************************************************************
*
* Summary:
*  The start function initializes the voltage DAC with the default values, 
*  and sets the power to the given level.  A power level of 0, is the same as executing
*  the stop function.
*
* Parameters:  
*  Power:   Sets power level between off (0) and (3) high power
*
* Return: 
*  (void) 
*
* Global variables:
*  VDAC_REF_1_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void VDAC_REF_1_Start(void) 
{  
    /* Hardware initiazation only needs to occure the first time */
    if ( VDAC_REF_1_initVar == 0)  
    { 
        VDAC_REF_1_Init();
       
        VDAC_REF_1_initVar = 1;
    }  
   
    /* Enable power to DAC */
    VDAC_REF_1_Enable();
    
    /* Set default value */
    VDAC_REF_1_SetValue(VDAC_REF_1_DEFAULT_DATA); 
}


/*******************************************************************************
* Function Name: VDAC_REF_1_Stop
********************************************************************************
*
* Summary:
*  Powers down DAC to lowest power state.
*
* Parameters:  
*  (void)  
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_Stop(void) 
{
   /* Disble power to DAC */
   VDAC_REF_1_PWRMGR &= ~VDAC_REF_1_ACT_PWR_EN;
   VDAC_REF_1_STBY_PWRMGR &= ~VDAC_REF_1_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: VDAC_REF_1_SetSpeed
********************************************************************************
*
* Summary:
*  Set DAC speed
*
* Parameters:  
*  power:   Sets speed value 
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_SetSpeed(uint8 speed) 
{
   /* Clear power mask then write in new value */
   VDAC_REF_1_CR0 &= ~VDAC_REF_1_HS_MASK ;    
   VDAC_REF_1_CR0 |=  ( speed & VDAC_REF_1_HS_MASK) ;    
}


/*******************************************************************************
* Function Name: VDAC_REF_1_SetRange
********************************************************************************
*
* Summary:
*  Set one of three current ranges.
*
* Parameters:  
*  Range:  Sets one of Three valid ranges.
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_SetRange(uint8 range) 
{
   VDAC_REF_1_CR0 &= ~VDAC_REF_1_RANGE_MASK ;      /* Clear existing mode */
   VDAC_REF_1_CR0 |= ( range & VDAC_REF_1_RANGE_MASK ) ; /*  Set Range  */
   VDAC_REF_1_DacTrim();
}


/*******************************************************************************
* Function Name: VDAC_REF_1_SetValue
********************************************************************************
*
* Summary:
*  Set 8-bit DAC value
*
* Parameters:  
*  value:  Sets DAC value between 0 and 255.
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
* Reenrancy: 
*  Yes
*******************************************************************************/
void VDAC_REF_1_SetValue(uint8 value) 
{
   VDAC_REF_1_Data = value;                             /*  Set Value  */
   
   /* PSOC3 silicons earlier to ES3 require a double write */
   #if (VDAC_REF_1_PSOC3_ES2 || VDAC_REF_1_PSOC5_ES1)
       VDAC_REF_1_Data = value;
   #endif
}


/*******************************************************************************
* Function Name: VDAC_REF_1_DacTrim
********************************************************************************
*
* Summary:
*  Set the trim value for the given range.
*
* Parameters:  
*   range:  1V or 4V range.  See constants.  
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void VDAC_REF_1_DacTrim(void) 
{
    uint8 mode;
    
    mode = ((VDAC_REF_1_CR0 & VDAC_REF_1_RANGE_MASK) >> 2) + VDAC_REF_1_TRIM_M7_1V_RNG_OFFSET;
    
    VDAC_REF_1_TR = CY_GET_XTND_REG8((uint8 *)(VDAC_REF_1_DAC_TRIM_BASE + mode));
}


/* [] END OF FILE */
