/*******************************************************************************
* File Name: VDAC_REF_2.h  
* Version 1.60
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Voltage DAC (vDAC8) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_VDAC8_VDAC_REF_2_H) 
#define CY_VDAC8_VDAC_REF_2_H

#include "cytypes.h"
#include "cyfitter.h"


/* PSoC3 ES2 or early */
#define VDAC_REF_2_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))                    
/* PSoC5 ES1 or early */
#define VDAC_REF_2_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define VDAC_REF_2_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define VDAC_REF_2_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct VDAC_REF_2_backupStruct
{
    uint8 enableState; 
	uint8 data_value;
}VDAC_REF_2_backupStruct;


/***************************************
*        Function Prototypes 
***************************************/

void VDAC_REF_2_Start(void);
void VDAC_REF_2_Stop(void)            ;
void VDAC_REF_2_SetSpeed(uint8 speed) ;
void VDAC_REF_2_SetRange(uint8 range) ;
void VDAC_REF_2_SetValue(uint8 value) ;
void VDAC_REF_2_DacTrim(void)         ;
void VDAC_REF_2_Init(void)            ;
void VDAC_REF_2_Enable(void)          ;
void VDAC_REF_2_SaveConfig(void);
void VDAC_REF_2_RestoreConfig(void);
void VDAC_REF_2_Sleep(void);
void VDAC_REF_2_Wakeup(void)          ;
  
  
/***************************************
*            API Constants
***************************************/

/* SetRange constants */

#define VDAC_REF_2_RANGE_1V       0x00u
#define VDAC_REF_2_RANGE_4V       0x04u


/* Power setting for Start API  */
#define VDAC_REF_2_LOWSPEED       0x00u
#define VDAC_REF_2_HIGHSPEED      0x02u


/***************************************
*  Initialization Parameter Constants
***************************************/

#define VDAC_REF_2_DEFAULT_RANGE    0     /* Default DAC range */
#define VDAC_REF_2_DEFAULT_SPEED    0     /* Default DAC speed */
#define VDAC_REF_2_DEFAULT_CNTL     0x00u             /* Default Control */
#define VDAC_REF_2_DEFAULT_STRB     0    /* Default Strobe mode */
#define VDAC_REF_2_DEFAULT_DATA     75  /* Initial DAC value */
#define VDAC_REF_2_DEFAULT_DATA_SRC 0    /* Default Data Source */


/***************************************
*              Registers        
***************************************/

#define VDAC_REF_2_CR0         (* (reg8 *) VDAC_REF_2_viDAC8__CR0 )
#define VDAC_REF_2_CR1         (* (reg8 *) VDAC_REF_2_viDAC8__CR1 )
#define VDAC_REF_2_Data        (* (reg8 *) VDAC_REF_2_viDAC8__D )
#define VDAC_REF_2_Data_PTR    (  (reg8 *) VDAC_REF_2_viDAC8__D )
#define VDAC_REF_2_Strobe      (* (reg8 *) VDAC_REF_2_viDAC8__STROBE )
#define VDAC_REF_2_SW0         (* (reg8 *) VDAC_REF_2_viDAC8__SW0 )
#define VDAC_REF_2_SW2         (* (reg8 *) VDAC_REF_2_viDAC8__SW2 )
#define VDAC_REF_2_SW3         (* (reg8 *) VDAC_REF_2_viDAC8__SW3 )
#define VDAC_REF_2_SW4         (* (reg8 *) VDAC_REF_2_viDAC8__SW4 )
#define VDAC_REF_2_TR          (* (reg8 *) VDAC_REF_2_viDAC8__TR )
#define VDAC_REF_2_PWRMGR      (* (reg8 *) VDAC_REF_2_viDAC8__PM_ACT_CFG )  /* Power manager */
#define VDAC_REF_2_STBY_PWRMGR (* (reg8 *) VDAC_REF_2_viDAC8__PM_STBY_CFG )  /* Standby Power manager */


/***************************************
*         Register Constants       
***************************************/

/* CR0 vDac Control Register 0 definitions */

/* Bit Field  DAC_HS_MODE                  */
#define VDAC_REF_2_HS_MASK        0x02u
#define VDAC_REF_2_HS_LOWPOWER    0x00u
#define VDAC_REF_2_HS_HIGHSPEED   0x02u

/* Bit Field  DAC_MODE                  */
#define VDAC_REF_2_MODE_MASK      0x10u
#define VDAC_REF_2_MODE_V         0x00u
#define VDAC_REF_2_MODE_I         0x10u

/* Bit Field  DAC_RANGE                  */
#define VDAC_REF_2_RANGE_MASK     0x0Cu
#define VDAC_REF_2_RANGE_0        0x00u
#define VDAC_REF_2_RANGE_1        0x04u

/* CR1 iDac Control Register 1 definitions */

/* Bit Field  DAC_MX_DATA                  */
#define VDAC_REF_2_SRC_MASK       0x20u
#define VDAC_REF_2_SRC_REG        0x00u
#define VDAC_REF_2_SRC_UDB        0x20u

/* This bit enable reset from UDB array      */
#define VDAC_REF_2_RESET_MASK     0x10u
#define VDAC_REF_2_RESET_ENABLE   0x10u
#define VDAC_REF_2_RESET_DISABLE  0x00u

/* This bit enables data from DAC bus      */
#define VDAC_REF_2_DACBUS_MASK     0x20u
#define VDAC_REF_2_DACBUS_ENABLE   0x20u
#define VDAC_REF_2_DACBUS_DISABLE  0x00u

/* DAC STROBE Strobe Control Register definitions */

/* Bit Field  DAC_MX_STROBE                  */
#define VDAC_REF_2_STRB_MASK     0x08u
#define VDAC_REF_2_STRB_EN       0x08u
#define VDAC_REF_2_STRB_DIS      0x00u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define VDAC_REF_2_ACT_PWR_EN   VDAC_REF_2_viDAC8__PM_ACT_MSK /* Power enable mask */ 
#define VDAC_REF_2_STBY_PWR_EN  VDAC_REF_2_viDAC8__PM_STBY_MSK  /* Standby Power enable mask */


/***********************************************************************************
*              Trim    
* Note - VDAC trim values are stored in the "Customer Table" area in 
* Row 1 of the Hidden Flash.  There are 8 bytes of trim data for each VDAC block.
* The values are:
*       I Gain offset, min range, Sourcing
*       I Gain offset, min range, Sinking
*       I Gain offset, med range, Sourcing
*       I Gain offset, med range, Sinking
*       I Gain offset, max range, Sourcing
*       I Gain offset, max range, Sinking
*       V Gain offset, 1V range
*       V Gain offset, 4V range
*
* The data set for the 4 VDACs are arranged using a left side/right side approach:
*   Left 0, Left 1, Right 0, Right 1.
* When mapped to the VDAC0 thru VDAC3 as:
*   VDAC 0, VDAC 2, VDAC 1, VDAC 3
************************************************************************************/
#define VDAC_REF_2_TRIM_M7_1V_RNG_OFFSET  0x06u
#define VDAC_REF_2_TRIM_M8_4V_RNG_OFFSET  0x07u

#define VDAC_REF_2_DAC_TRIM_BASE     (VDAC_REF_2_viDAC8__TRIM__M1)

#endif /* CY_VDAC8_VDAC_REF_2_H  */


/* [] END OF FILE */


