/*******************************************************************************
* File Name: WaveDAC8_1.h  
* Version 1.50
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Waveform DAC (WaveDAC8) Component.
*
*   Note: 
*     
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"
#include <WaveDAC8_1_Wave1_DMA_dma.h>
#include <WaveDAC8_1_Wave2_DMA_dma.h>

#define WaveDAC8_1_DEFAULT_RANGE    1     /* Default DAC range */
#define WaveDAC8_1_DACMODE (((1 == 0) || ( 1 == 1 ))?0:1)
#define WaveDAC8_1_VOLT_MODE     0
#define WaveDAC8_1_CURRENT_MODE  1



#if(WaveDAC8_1_DACMODE == WaveDAC8_1_VOLT_MODE)
#include <WaveDAC8_1_VDAC8.h>
#else
#include <WaveDAC8_1_IDAC8.h>
#endif

#if(1)  
   #include <WaveDAC8_1_DacClk.h>
#endif

#if !defined(CY_WDAC8_WaveDAC8_1_H) 
#define CY_WDAC8_WaveDAC8_1_H


#define WaveDAC8_1_Wave1_DMA_TD_TERMOUT_EN ((WaveDAC8_1_Wave1_DMA__TERMOUT0_EN ? TD_TERMOUT0_EN : 0) | \
    (WaveDAC8_1_Wave1_DMA__TERMOUT1_EN ? TD_TERMOUT1_EN : 0))
	
#define WaveDAC8_1_Wave2_DMA_TD_TERMOUT_EN ((WaveDAC8_1_Wave2_DMA__TERMOUT0_EN ? TD_TERMOUT0_EN : 0) | \
    (WaveDAC8_1_Wave2_DMA__TERMOUT1_EN ? TD_TERMOUT1_EN : 0))
	

#define WaveDAC8_1_Wave1_DMA_BYTES_PER_BURST 1	
#define WaveDAC8_1_Wave1_DMA_REQUEST_PER_BURST 1
#define WaveDAC8_1_Wave2_DMA_BYTES_PER_BURST 1	
#define WaveDAC8_1_Wave2_DMA_REQUEST_PER_BURST 1

/***************************************
*   Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _WaveDAC8_1_backupStruct
{
    uint8   enableState;
}   WaveDAC8_1_BACKUP_STRUCT;


/***************************************
*        Function Prototypes 
***************************************/

void    WaveDAC8_1_Start(void);
void    WaveDAC8_1_Init(void);
void    WaveDAC8_1_Enable(void);
void    WaveDAC8_1_Stop(void);
void    WaveDAC8_1_SetSpeed(uint8 speed);
void    WaveDAC8_1_SetRange(uint8 range);
void    WaveDAC8_1_SetValue(uint8 value);
void 	WaveDAC8_1_DacTrim(void);

void    WaveDAC8_1_Wave1Setup( uint8 * WavePtr, uint16 SampleSize);
void    WaveDAC8_1_Wave2Setup( uint8 * WavePtr, uint16 SampleSize);

void    WaveDAC8_1_SaveConfig(void);
void    WaveDAC8_1_RestoreConfig(void);
void    WaveDAC8_1_Sleep(void);
void    WaveDAC8_1_Wakeup(void);
  
  
/***************************************
*            API Constants
***************************************/

/* SetRange constants */

#define WaveDAC8_1_RANGE_1V       (0x00u)
#define WaveDAC8_1_RANGE_4V       (0x04u)

#define WaveDAC8_1_RANGE_32uA     (0x00u)
#define WaveDAC8_1_RANGE_255uA    (0x04u)
#define WaveDAC8_1_RANGE_2mA      (0x08u)
#define WaveDAC8_1_RANGE_2048uA   (0x08u)


/* Power setting for Start API  */
#define WaveDAC8_1_LOWSPEED       0x00u
#define WaveDAC8_1_HIGHSPEED      0x02u


/***************************************
*  Initialization Parameter Constants
***************************************/

#define WaveDAC8_1_WAVE1_TYPE    1     /* Waveform for wave1 */
#define WaveDAC8_1_WAVE2_TYPE    10     /* Waveform for wave2 */
#define WaveDAC8_1_WAVE1_LENGTH  500   /* Length for wave1 */
#define WaveDAC8_1_WAVE2_LENGTH  3683   /* Length for wave2 */
#define WaveDAC8_1_CLOCK_SRC     1      /* Clock SRC 0=Ext, 1=Int */

#define WaveDAC8_1_SINE_WAVE       0x00
#define WaveDAC8_1_SQUARE_WAVE     0x01
#define WaveDAC8_1_TRIANGLE_WAVE   0x02
#define WaveDAC8_1_SAWTOOTH_WAVE   0x03

#define WaveDAC8_1_CLOCK_INT       0x01
#define WaveDAC8_1_CLOCK_EXT       0x00  


/***************************************
*              Registers        
***************************************/

#if(WaveDAC8_1_DACMODE == WaveDAC8_1_VOLT_MODE)
#define WaveDAC8_1_DAC8__D WaveDAC8_1_VDAC8_viDAC8__D
#else
#define WaveDAC8_1_DAC8__D WaveDAC8_1_IDAC8_viDAC8__D
#endif

/***************************************
*         Register Constants       
***************************************/

/* CR0 vDac Control Register 0 definitions */

/* Bit Field  DAC_HS_MODE                  */
#define WaveDAC8_1_HS_MASK        0x02u
#define WaveDAC8_1_HS_LOWPOWER    0x00u
#define WaveDAC8_1_HS_HIGHSPEED   0x02u

/* Bit Field  DAC_MODE                  */
#define WaveDAC8_1_MODE_MASK      0x10u
#define WaveDAC8_1_MODE_V         0x00u
#define WaveDAC8_1_MODE_I         0x10u

/* Bit Field  DAC_RANGE                  */
#define WaveDAC8_1_RANGE_MASK     0x0Cu
#define WaveDAC8_1_RANGE_0        0x00u
#define WaveDAC8_1_RANGE_1        0x04u
#define WaveDAC8_1_RANGE_2        0x08u
#define WaveDAC8_1_RANGE_3        0x0Cu
#define WaveDAC8_1_IDIR_MASK      0x04u

#define WaveDAC8_1_DAC_RANGE  (( 1 << 2 ) & WaveDAC8_1_RANGE_MASK )
#define WaveDAC8_1_DAC_POL    (( 1 >> 1 ) & WaveDAC8_1_IDIR_MASK )  

#endif /* CY_VDAC8_WaveDAC8_1_H  */
/* [] END OF FILE */



